# LicenseCredentials


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**printnanny_api_token** | **str** |  | [optional] 
**printnanny_api_url** | **str** |  | [optional] 
**honeycomb_dataset** | **str** |  | [optional] 
**honeycomb_api_key** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


